function [H1, H2, H12, M, C] = mutual_information(img1, img2)

% [H1, H2, H12, M, C] = mutual_information(img1, img2)
% 
% This function claculates the mutual infromation of two images. If the
% images have different size, then they are resize to the same size.
% img1  - first image
% img2  - second image
% H1    - entropy of first image
% H2    - entropy of second image
% H12   - joint entropy
% M     - mutual entropy
% C     - correlation matrix

%% Check the sizes of images
[k1, l1, m1] = size(img1);
[k2, l2, m2] = size(img2);

%% Check if the images are two-dimensional
if(m1 > 1 || m2 > 2)
    return;
end

%% Resize to the same size
if(k1 ~= k2 || l1 ~= l2)
    [img1, img2] = same_size(img1, img2);
    
    [k1, l1, m1] = size(img1);
    [k2, l2, m2] = size(img2);
end

%% Calculate entropies
H1 = entropy(img1);
H2 = entropy(img2);

%% Claculate joint entropy
h = zeros(256);

for i = 1:k1
    for j = 1:l1
        h(img1(i,j)+1,img2(i,j)+1)= h(img1(i,j)+1,img2(i,j)+1)+1;
    end
end
    
tmp = h./(k1*l1);
H12 = -sum(sum(tmp.*(log2(tmp+(tmp==0)))));

%% Mutual entropy
M = (H1 + H2 - H12);

%% Calculate correlation
C = normxcorr2(img1, imresize(img2, 1.1));