function [imr1, imr2] = same_size(img1, img2, method)

% [imr1, imr2] = same_size(img1, img2, method)
% 
% This function resize two images to fit the same size.
% img1      - first image
% img2      - second image
% method    - method used during the resize
%             {'nearest','bilinear','bicubic'}
% imr1      - resized first image
% imr2      - resized second image

%% Slect method
if(nargin < 3 || isempty(method))
    method = 'bicubic';
end

imr1 = img1;
imr2 = img2;

%% Find new size
m1 = size(imr1,1);
n1 = size(imr1,2);
m2 = size(imr2,1);
n2 = size(imr2,2);
m = min([m1 m2]);
n = min([n1 n2]);

%% Resize
if(m1 ~= m || n1 ~= n)
    imr1 = imresize(imr1, [m n], method);
end
if(m2 ~= m || n2 ~= n)
    imr2 = imresize(imr2, [m n], method);
end